boto v2.9.4 — boto v2.21.1

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »

# boto v2.9.4

date: | 2013/05/20

This release adds updated Elastic Transcoder support & fixes several bugs from recent releases & API updates.

## Features

- Updated Elastic Transcoder support - It now supports HLS, WebM, MPEG2-TS & a host of other features. (commit 89196a)

## Bugfixes

- Fixed a bug in the canonicalization of URLs on Windows. (commit 09ef8c)

- Fixed glacier part size bug (issue 1478, commit 9e04171)

- Fixed a bug in the bucket regex for S3 involving capital letters. (commit 950031)

- Fixed a bug where timestamps from Cloudformation would fail to be parsed. (commit b40542)

- Several documentation improvements/fixes:

  > - Added autodocs for many of the EC2 apis. (commit 79f939)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »